==> dateparser_0.7.2.orig.tar.gz: dateparser-0.7.2/dateparser/data/date_translation_data/ca.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "ca",
    "date_order": "DMY",
    "january": [
        "gener",
        "gen",
        "de gener",
        "de gen"
    ],
    "february": [
        "febrer",
        "febr",
        "de febrer",
        "de febr"
    ],
    "march": [
        "març",
        "de març"
    ],
    "april": [
        "abril",
        "abr",
        "d'abril",
        "d'abr"
    ],
    "may": [
        "maig",
        "de maig"
    ],
    "june": [
        "juny",
        "de juny"
    ],
    "july": [
        "juliol",
        "jul",
        "de juliol",
        "de jul"
    ],
    "august": [
        "agost",
        "ag",
        "d'agost",
        "d'ag"
    ],
    "september": [
        "setembre",
        "set",
        "de setembre",
        "de set"
    ],
    "october": [
        "octubre",
        "oct",
        "d'octubre",
        "d'oct"
    ],
    "november": [
        "novembre",
        "nov",
        "de novembre",
        "de nov"
    ],
    "december": [
        "desembre",
        "des",
        "de desembre",
        "de des"
    ],
    "monday": [
        "dilluns",
        "dl"
    ],
    "tuesday": [
        "dimarts",
        "dt"
    ],
    "wednesday": [
        "dimecres",
        "dc"
    ],
    "thursday": [
        "dijous",
        "dj"
    ],
    "friday": [
        "divendres",
        "dv"
    ],
    "saturday": [
        "dissabte",
        "ds"
    ],
    "sunday": [
        "diumenge",
        "dg"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "any"
    ],
    "month": [
        "mes"
    ],
    "week": [
        "setmana",
        "setm"
    ],
    "day": [
        "dia"
    ],
    "hour": [
        "hora",
        "h"
    ],
    "minute": [
        "minut",
        "min"
    ],
    "second": [
        "segon",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "l'any passat"
        ],
        "0 year ago": [
            "enguany"
        ],
        "in 1 year": [
            "l'any que ve"
        ],
        "1 month ago": [
            "el mes passat",
            "mes passat"
        ],
        "0 month ago": [
            "aquest mes"
        ],
        "in 1 month": [
            "el mes que ve",
            "mes vinent"
        ],
        "1 week ago": [
            "la setmana passada",
            "la setm passada",
            "setm passada"
        ],
        "0 week ago": [
            "aquesta setmana",
            "aquesta setm"
        ],
        "in 1 week": [
            "la setmana que ve",
            "la setm que ve",
            "setm vinent",
            "la setmana vinent",
            "la pròxima setmana",
            "la propera setmana"
        ],
        "1 day ago": [
            "ahir"
        ],
        "0 day ago": [
            "avui",
            "hui"
        ],
        "in 1 day": [
            "demà"
        ],
        "0 hour ago": [
            "aquesta hora"
        ],
        "0 minute ago": [
            "aquest minut"
        ],
        "0 second ago": [
            "ara"
        ],
        "2 day ago": [
            "despús-ahir",
            "abans-d’ahir",
            "dellà-ahir"
        ],
        "in 2 day": [
            "endemà",
            "sendemà",
            "despús-demà",
            "demà passat",
            "passat demà"
        ],
        "in 3 day": [
            "endemà passat"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "d'aquí a (\\d+) any",
            "d'aquí a (\\d+) anys"
        ],
        "\\1 year ago": [
            "fa (\\d+) any",
            "fa (\\d+) anys"
        ],
        "in \\1 month": [
            "d'aquí a (\\d+) mes",
            "d'aquí a (\\d+) mesos"
        ],
        "\\1 month ago": [
            "fa (\\d+) mes",
            "fa (\\d+) mesos"
        ],
        "in \\1 week": [
            "d'aquí a (\\d+) setmana",
            "d'aquí a (\\d+) setmanes",
            "d'aquí a (\\d+) setm"
        ],
        "\\1 week ago": [
            "fa (\\d+) setmana",
            "fa (\\d+) setmanes",
            "fa (\\d+) setm"
        ],
        "in \\1 day": [
            "d'aquí a (\\d+) dia",
            "d'aquí a (\\d+) dies"
        ],
        "\\1 day ago": [
            "fa (\\d+) dia",
            "fa (\\d+) dies"
        ],
        "in \\1 hour": [
            "d'aquí a (\\d+) hora",
            "d'aquí a (\\d+) hores",
            "d'aquí a (\\d+) h",
            "d‘aquí a (\\d+) h"
        ],
        "\\1 hour ago": [
            "fa (\\d+) hora",
            "fa (\\d+) hores",
            "fa (\\d+) h"
        ],
        "in \\1 minute": [
            "d'aquí a (\\d+) minut",
            "d'aquí a (\\d+) minuts",
            "d'aquí a (\\d+) min"
        ],
        "\\1 minute ago": [
            "fa (\\d+) minut",
            "fa (\\d+) minuts",
            "fa (\\d+) min"
        ],
        "in \\1 second": [
            "d'aquí a (\\d+) segon",
            "d'aquí a (\\d+) segons",
            "d'aquí a (\\d+) s"
        ],
        "\\1 second ago": [
            "fa (\\d+) segon",
            "fa (\\d+) segons",
            "fa (\\d+) s"
        ]
    },
    "locale_specific": {
        "ca-FR": {
            "name": "ca-FR"
        },
        "ca-IT": {
            "name": "ca-IT"
        },
        "ca-AD": {
            "name": "ca-AD"
        }
    },
    "skip": [
        "de",
        "del",
        "l'",
        "i",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "pertain": [
        "de",
        "del"
    ],
    "in": [
        "en"
    ],
    "simplifications": [
        {
            "una": "1"
        },
        {
            "un": "1"
        }
    ]
}

==> dateparser_1.1.1.orig.tar.gz: dateparser-1.1.1/dateparser/data/date_translation_data/ca.py <==
info = {
    "name": "ca",
    "date_order": "DMY",
    "january": [
        "de gen",
        "de gener",
        "gen",
        "gener"
    ],
    "february": [
        "de febr",
        "de febrer",
        "febr",
        "febrer"
    ],
    "march": [
        "de març",
        "març"
    ],
    "april": [
        "abr",
        "abril",
        "d'abr",
        "d'abril"
    ],
    "may": [
        "de maig",
        "maig"
    ],
    "june": [
        "de juny",
        "juny"
    ],
    "july": [
        "de jul",
        "de juliol",
        "jul",
        "juliol"
    ],
    "august": [
        "ag",
        "agost",
        "d'ag",
        "d'agost"
    ],
    "september": [
        "de set",
        "de setembre",
        "set",
        "setembre"
    ],
    "october": [
        "d'oct",
        "d'octubre",
        "oct",
        "octubre"
    ],
    "november": [
        "de nov",
        "de novembre",
        "nov",
        "novembre"
    ],
    "december": [
        "de des",
        "de desembre",
        "des",
        "desembre"
    ],
    "monday": [
        "dilluns",
        "dl"
    ],
    "tuesday": [
        "dimarts",
        "dt"
    ],
    "wednesday": [
        "dc",
        "dimecres"
    ],
    "thursday": [
        "dijous",
        "dj"
    ],
    "friday": [
        "divendres",
        "dv"
    ],
    "saturday": [
        "dissabte",
        "ds"
    ],
    "sunday": [
        "dg",
        "diumenge"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "any"
    ],
    "month": [
        "mes"
    ],
    "week": [
        "setm",
        "setmana"
    ],
    "day": [
        "dia"
    ],
    "hour": [
        "h",
        "hora"
    ],
    "minute": [
        "min",
        "minut"
    ],
    "second": [
        "s",
        "segon"
    ],
    "relative-type": {
        "0 day ago": [
            "avui",
            "hui"
        ],
        "0 hour ago": [
            "aquesta hora"
        ],
        "0 minute ago": [
            "aquest minut"
        ],
        "0 month ago": [
            "aquest mes"
        ],
        "0 second ago": [
            "ara"
        ],
        "0 week ago": [
            "aquesta setm",
            "aquesta setmana"
        ],
        "0 year ago": [
            "enguany"
        ],
        "1 day ago": [
            "ahir"
        ],
        "1 month ago": [
            "el mes passat",
            "mes passat"
        ],
        "1 week ago": [
            "la setm passada",
            "la setmana passada",
            "setm passada"
        ],
        "1 year ago": [
            "l'any passat"
        ],
        "in 1 day": [
            "demà"
        ],
        "in 1 month": [
            "el mes que ve",
            "mes vinent"
        ],
        "in 1 week": [
            "la setm que ve",
            "la setmana que ve",
            "setm vinent",
            "la setmana vinent",
            "la pròxima setmana",
            "la propera setmana"
        ],
        "in 1 year": [
            "l'any que ve"
        ],
        "2 day ago": [
            "despús-ahir",
            "abans-d’ahir",
            "dellà-ahir"
        ],
        "in 2 day": [
            "endemà",
            "sendemà",
            "despús-demà",
            "demà passat",
            "passat demà"
        ],
        "in 3 day": [
            "endemà passat"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "fa (\\d+) dia",
            "fa (\\d+) dies"
        ],
        "\\1 hour ago": [
            "fa (\\d+) h",
            "fa (\\d+) hora",
            "fa (\\d+) hores"
        ],
        "\\1 minute ago": [
            "fa (\\d+) min",
            "fa (\\d+) minut",
            "fa (\\d+) minuts"
        ],
        "\\1 month ago": [
            "fa (\\d+) mes",
            "fa (\\d+) mesos"
        ],
        "\\1 second ago": [
            "fa (\\d+) s",
            "fa (\\d+) segon",
            "fa (\\d+) segons"
        ],
        "\\1 week ago": [
            "fa (\\d+) setm",
            "fa (\\d+) setmana",
            "fa (\\d+) setmanes"
        ],
        "\\1 year ago": [
            "fa (\\d+) any",
            "fa (\\d+) anys"
        ],
        "in \\1 day": [
            "d'aquí a (\\d+) dia",
            "d'aquí a (\\d+) dies"
        ],
        "in \\1 hour": [
            "d'aquí a (\\d+) h",
            "d'aquí a (\\d+) hora",
            "d'aquí a (\\d+) hores",
            "d‘aquí a (\\d+) h"
        ],
        "in \\1 minute": [
            "d'aquí a (\\d+) min",
            "d'aquí a (\\d+) minut",
            "d'aquí a (\\d+) minuts"
        ],
        "in \\1 month": [
            "d'aquí a (\\d+) mes",
            "d'aquí a (\\d+) mesos"
        ],
        "in \\1 second": [
            "d'aquí a (\\d+) s",
            "d'aquí a (\\d+) segon",
            "d'aquí a (\\d+) segons"
        ],
        "in \\1 week": [
            "d'aquí a (\\d+) setm",
            "d'aquí a (\\d+) setmana",
            "d'aquí a (\\d+) setmanes"
        ],
        "in \\1 year": [
            "d'aquí a (\\d+) any",
            "d'aquí a (\\d+) anys"
        ]
    },
    "locale_specific": {
        "ca-AD": {
            "name": "ca-AD"
        },
        "ca-FR": {
            "name": "ca-FR"
        },
        "ca-IT": {
            "name": "ca-IT"
        }
    },
    "skip": [
        "de",
        "del",
        "i",
        "l'",
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ],
    "pertain": [
        "de",
        "del"
    ],
    "in": [
        "en"
    ],
    "simplifications": [
        {
            "una": "1"
        },
        {
            "un": "1"
        }
    ]
}
